@@ -1,4 +1,4 @@
 from .error import Error
 from .reader import BatchReader, read_arrow_batches_from_odbc
 
-__all__ = ['BatchReader', 'read_arrow_batches_from_odbc', 'Error']
\ No newline at end of file
+__all__ = ["BatchReader", "read_arrow_batches_from_odbc", "Error"]
