@@ -14,7 +14,7 @@ use arrow_odbc::{
         record_batch::RecordBatchReader,
     },
     odbc_api::{CursorImpl, StatementConnection},
-    OdbcReader,
+    OdbcReader, BufferAllocationOptions,
 };
 
 use crate::{try_, ArrowOdbcError, OdbcConnection, parameter::ArrowOdbcParameter};
@@ -35,11 +35,19 @@ pub struct ArrowOdbcReader(OdbcReader<CursorImpl<StatementConnection<'static>>>)
 ///   afterwards.
 /// * `query_buf` must point to a valid utf-8 string
 /// * `query_len` describes the len of `query_buf` in bytes.
-/// * `reader_out` in case of success this will point to an instance of `ArrowOdbcReader`.
-///   Ownership is transferred to the caller.
 /// * `parameters` must contain only valid pointers. This function takes ownership of all of them
 ///   independent if the function succeeds or not. Yet it does not take ownership of the array
 ///   itself.
+/// * `parameters_len` number of elements in parameters.
+/// * `max_text_size` optional upper bound for the size of text columns. Use `0` to indicate that no
+///   uppper bound applies.
+/// * `max_binary_size` optional upper bound for the size of binary columns. Use `0` to indicate
+///   that no uppper bound applies.
+/// * `fallibale_allocations`: `TRUE` if allocations should return an error, `FALSE` if it is fine
+///   to abort the process. Enabling might have a performance overhead, so it might be desirable to
+///   disable it, if you know there is enough memory available.
+/// * `reader_out` in case of success this will point to an instance of `ArrowOdbcReader`.
+///   Ownership is transferred to the caller.
 #[no_mangle]
 pub unsafe extern "C" fn arrow_odbc_reader_make(
     connection: NonNull<OdbcConnection>,
@@ -48,6 +56,9 @@ pub unsafe extern "C" fn arrow_odbc_reader_make(
     batch_size: usize,
     parameters: *const *mut ArrowOdbcParameter,
     parameters_len: usize,
+    max_text_size: usize,
+    max_binary_size: usize,
+    fallibale_allocations: bool,
     reader_out: *mut *mut ArrowOdbcReader,
 ) -> *mut ArrowOdbcError {
     let query = slice::from_raw_parts(query_buf, query_len);
@@ -64,9 +75,27 @@ pub unsafe extern "C" fn arrow_odbc_reader_make(
             .collect()
     };
 
+    let max_text_size = if max_text_size == 0 {
+        None
+    } else {
+        Some(max_text_size)
+    };
+
+    let max_binary_size = if max_binary_size == 0 {
+        None
+    } else {
+        Some(max_binary_size)
+    };
+
+    let buffer_allocation_options = BufferAllocationOptions {
+        max_text_size,
+        max_binary_size,
+        fallibale_allocations,
+    };
+
     let maybe_cursor = try_!(connection.0.into_cursor(query, &parameters[..]));
     if let Some(cursor) = maybe_cursor {
-        let reader = try_!(OdbcReader::new(cursor, batch_size));
+        let reader = try_!(OdbcReader::with(cursor, batch_size, None, buffer_allocation_options));
         *reader_out = Box::into_raw(Box::new(ArrowOdbcReader(reader)))
     } else {
         *reader_out = null_mut()
